@@ -142,7 +142,7 @@ static OidInfo oid_info[] = {
 static OidInfo*
 find_oid_info (GQuark oid)
 {
-	static volatile gsize inited_oids = 0;
+	static size_t inited_oids = 0;
 	int i;
 
 	g_return_val_if_fail (oid != 0, NULL);
