@@ -86,10 +86,6 @@ main (int argc, char *argv[])
 	GError *error = NULL;
 	GtkWindow *window;
 
-#if !GLIB_CHECK_VERSION(2,35,0)
-	g_type_init ();
-#endif
-
 #ifdef HAVE_LOCALE_H
 	/* internationalisation */
 	setlocale (LC_ALL, "");
